;************************************************

;* Module to setup the desired register address *

;* Enter with zl (r30) holding the Register Addr*

;* Same code as in Burst RD/WR src.             *

;************************************************

SetAddress:

	sbi	DDRD,2	; Set DIO to output

	ldi 	zh,8	; Load the shift counter

addrlp:	cbi	PORTD,2	; assume data = 0

	lsr	zl	; shift LSB into carry flag

	brcc	addr1	; was it a '1'

	sbi	PORTD,2	; Yes, set Dout = 1

	nop

addr1:	sbi	PORTD,4	; Clk the bit into the 1305

	nop

	cbi	PORTD,4	; Return Clk to 0

	dec	zh	; All 8 bits done ?

	brne	addrlp	; No, keep going

	ret		; return to caller

;

;*******************************************

;* Read a specified RTC register contents. *

;* enter w/zl (r30) = RTC register address *

;* On return, the zl (r30) has the RTC data*

;*******************************************

ReadRTCreg:

	cbi 	PORTD,4	; Set sclk = 0

	sbi 	PORTD,6	; Set Chip Enable = 1 (True)

	rcall	SetAddress ; Set the current RTC register address

	sbi 	PORTD,2	; enable pull-up resistor

	cbi 	DDRD,2	; Set DIO to Input

	ldi 	zh,8	; Load the bit shift counter

rdclklp:

	sbi 	PORTD,4	; Set sclk = 1

	clc		; Assume DIN = 0

	sbic	PIND,2	; Does DIN = 0 ?

	sec		; No, DIN = 'C' = 1

	ror 	zl	; Shift into bit accumulator

	cbi 	PORTD,4	; Set sclk = 0

	dec 	zh	; Dec bit count. Have all 8 bits been read ?

	brne	rdclklp	; No, loop until all 8 bits are in.

	cbi 	PORTD,6	; Yes, set Chip Enable = 0 (False)

	ret		; return to caller

;

;*******************************************

;* Write a specified RTC register contents.*

;* enter w/zh (r31) = RTC register address *

;* and     zl (r30) = RTC data to write    *

;*******************************************

WriteRTCreg:

	ori 	zh,0x80	; Set the RTC Write data mode by setting bit 7

	ldi 	r24,16	; Bit count = 16bits. (8 bits of address and 8 bits of data)

	cbi 	PORTD,4	; Set sclk = 0

	sbi 	DDRD,2	; Set DIO to Output

	sbi 	PORTD,6	; Set Chip Enable = 1 (True)

wrclklp1:

	cbi 	PORTD,2	; Assume Data = 0

	lsr 	zl	; shift the LSB of 16bits out

	ror 	zh

	brcc	wrc0	; Was the bit a 0 ?

	sbi 	PORTD,2	; No, Dout = 1

	nop		; Note: this may be required for the faster AVRs

wrc0:

	sbi 	PORTD,4	; Set sclk = 1

	nop

	cbi 	PORTD,4	; Set sclk = 0

	dec 	r24	; Have all 16 data bits been sent ?

	brne	wrclklp1 ; No, loop until done.

	cbi 	PORTD,6	; Yes, Set Chip Enable = 0 (False)

	ret		; and return to caller.

;

;*******************************************

;* Enter this module to Set the Control Reg*

;* Set zl (r30) for the new register value *

;* Bit 7 = /EOSC.  0 = OSC on, 1 = OSC off *

;* Bit 6 = WP 1 = Write Protect, 0 = WP off*

;* Bit 2 = ISR source. (see .PDF file      *

;* Bit 1 = Alarm 1 IRQ Enable              *

;* Bit 0 = Alarm 0 IRQ Enable              *

;*******************************************

WriteControlReg:

	ldi 	zh,0x8f

	rjmp	WriteRTCreg

;

;*******************************************

;* Enter this module to RD the Control Reg *

;* zl (r30) returns Control Register value *

;*******************************************

ReadControlReg:

	ldi 	zl,0x0f

	rjmp	ReadRTCreg

;

;*******************************************

;* Enter this module to Set the Status Reg *

;* Set zl (r30) for the new register value *

;*******************************************

WriteStatusReg:

	ldi 	zh,0x90

	rjmp	WriteRTCreg

;

;*******************************************

;* Enter this module to RD the Status Reg  *

;* zl (r30) returns Status Register value  *

;* zl.0 has the Alarm 0 match IRQ status.  *

;* zl.1 has the Alarm 1 match IRQ status.  *

;*******************************************

ReadStatusReg:

	ldi 	zl,0x10

	rjmp	ReadRTCreg

;

