;************************************************

;* DIO   is PORTD.2

;* SCLK  is PORTD.4

;* CENAB is PORTD.6

;*

;* The first register is the Seconds counter (0-59)

;* Here is the AVR Sram byte order:

;* seconds, minutes, hours, day-of-week,

;* day-of-month, month, year

;* Note: ALL the RTC registers are in BCD format

;************************************************





;************************************************

;* Module to setup the desired register address *

;************************************************

SetAddress:

	sbi	DDRD,2	; Set DIO to output

	ldi 	zh,8	; Load the shift counter

addrlp:	cbi	PORTD,2	; assume data = 0

	lsr	zl	; shift LSB into carry flag

	brcc	addr1	; was it a '1'

	sbi	PORTD,2	; Yes, set Dout = 1

	nop

addr1:	sbi	PORTD,4	; Clk the bit into the 1305

	nop

	cbi	PORTD,4	; Return Clk to 0

	dec	zh	; All 8 bits done ?

	brne	addrlp	; No, keep going

	ret		; return to caller

;

;************************************************

;* Read the current time from seconds to year   *

;* Enter this function w/r24 holding the total  *

;* number of bytes to Read, and the zl register *

;* with the 1305 start address                  *

;************************************************

BurstRead:

	ldi	yl,low(seconds)	; Start with seconds

	ldi	yh,high(seconds)

	cbi 	PORTD,4		; Initialize Clk=0

	sbi 	PORTD,6		; Enable the DS1305

	rcall	SetAddress	; Inform the DS1305 of address

;** Remember, the input & output pins on the DS1305 are tied together!

;** So we have to turn the AVR data direction register 'around'

;**  in order to Read the Data In pin.

	sbi 	PORTD,2		; enable pull-up resistor

	cbi 	DDRD,2		; Set DIO to input

burstlp:

	ldi	zh,8		; Read 8 bits of data at a time

burstlp2:			; and keep the AVR/1305 in sync!

	sbi 	PORTD,4		; Clk the DS1305 for it's data bit

	clc			; Assume the data bit = 0

	sbic	PIND,2		; Does it = 0 ?

	sec			; No, set the carry

	ror 	zl		; Rotate the carry bit into the data byte

	cbi 	PORTD,4		; Clear the Clk line

	dec 	zh		; Have we received all 8 bits ?

	brne	burstlp2	; No, loop until all 8 have been received

	st	y+,zl		; Yes, save the byte to current Sram and inc 'y'

	dec	r24		; Have all the bytes requested been Read ?

	brne	burstlp		; No, Read 'x' number of bytes from the DS1305

	cbi 	PORTD,6		; Yes, Dis-able the DS1305

	ret			; return to caller

;

;************************************************

;* Write the current time from seconds to year  *

;* Enter this function w/r24 holding the total  *

;* number of bytes to write, and the zl register*

;* with the 1305 start address.                 *

;************************************************

BurstWrite:

	ldi	yl,low(seconds)

	ldi	yh,high(seconds)

	cbi 	PORTD,4		; Make sure sclk is low before DS1305 Enable

	sbi 	PORTD,6		; Enable the 1305

	ori	zl,0x80		; Set bit 7 for write data operation!

	rcall	SetAddress	; Select the needed register start point

wburstlp:

	ld	zl,y+		; Get the byte pointed to by the yl,yh register pair.

	ldi	zh,8		; Keep the 1305 bits in sync

wburstlp2:

	cbi 	PORTD,2		; Assume data = 0

	lsr 	zl		; Shift out LSB -> 'C'arry flag

	brcc	bwrc0		; Does the bit = 0 ?

	sbi 	PORTD,2		; No, set it to 1

bwrc0:	sbi 	PORTD,4		; Set the 1305 SCLK = 1

	nop			; Allow the 1305 time to clk it in.

	cbi 	PORTD,4		; Set the SCLK = 0

	dec 	zh		; Are all 8bits done ?

	brne	wburstlp2	; No, loop until all 8bits are done.

	dec	r24		; Have all bytes been sent ?

	brne	wburstlp	; No, keep going

	cbi 	PORTD,6		; Yes, dis-able the 1305

	ret			; return to caller

;



